@@ -21,18 +21,11 @@
 #
 # ---------------------------------------------------------------------------
 
-# imports
-
-# PySol imports
-from pysollib.gamedb import registerGame, GameInfo, GI
 from pysollib.game import Game
-from pysollib.layout import Layout
+from pysollib.gamedb import GI, GameInfo, registerGame
 from pysollib.hint import DefaultHint
+from pysollib.layout import Layout
 from pysollib.pysoltk import MfxCanvasText
-
-from pysollib.util import ANY_RANK, ANY_SUIT, JACK, KING, NO_RANK, QUEEN, \
-        UNLIMITED_CARDS, UNLIMITED_REDEALS
-
 from pysollib.stack import \
         AbstractFoundationStack, \
         BasicRowStack, \
@@ -41,13 +34,15 @@ from pysollib.stack import \
         FaceUpWasteTalonStack, \
         InitialDealTalonStack, \
         OpenStack, \
+        ReserveStack, \
         Stack, \
         StackWrapper, \
         TalonStack, \
         WasteStack, \
         WasteTalonStack, \
-        getNumberOfFreeStacks, \
-        ReserveStack
+        getNumberOfFreeStacks
+from pysollib.util import ANY_RANK, ANY_SUIT, JACK, KING, NO_RANK, QUEEN, \
+        UNLIMITED_CARDS, UNLIMITED_REDEALS
 
 
 # ************************************************************************
@@ -87,8 +82,10 @@ class Pyramid_StackMethods:
     def _dropPairMove(self, n, other_stack, frames=-1, shadow=-1):
         if not self.game.demo:
             self.game.playSample("droppair", priority=200)
-        assert n == 1 and self.acceptsCards(
-            other_stack, [other_stack.cards[-1]])
+        if not (n == 1
+                and other_stack.cards
+                and self.acceptsCards(other_stack, [other_stack.cards[-1]])):
+            return
         old_state = self.game.enterState(self.game.S_FILL)
         f = self.game.s.foundations[0]
         self.game.moveMove(n, self, f, frames=frames, shadow=shadow)
