@@ -21,16 +21,12 @@
 #
 # ---------------------------------------------------------------------------
 
-# PySol imports
-from pysollib.mygettext import _
-from pysollib.gamedb import registerGame, GameInfo, GI
-from pysollib.mfxutil import kwdefault
 from pysollib.game import Game
-from pysollib.layout import Layout
+from pysollib.gamedb import GI, GameInfo, registerGame
 from pysollib.hint import CautiousDefaultHint
-
-from pysollib.util import KING, NO_RANK
-
+from pysollib.layout import Layout
+from pysollib.mfxutil import kwdefault
+from pysollib.mygettext import _
 from pysollib.stack import \
         AC_FoundationStack, \
         AC_RowStack, \
@@ -40,10 +36,7 @@ from pysollib.stack import \
         StackWrapper, \
         WasteStack, \
         WasteTalonStack
-
-# ************************************************************************
-# *
-# ************************************************************************
+from pysollib.util import KING, NO_RANK
 
 
 class Terrace_Talon(WasteTalonStack):
