@@ -22,19 +22,13 @@
 # ---------------------------------------------------------------------------##
 
 
-# imports
 import os
 
-# settings
-from pysollib.settings import TOOLKIT
-
-# PySol imports
-from pysollib.resource import CSI
 from pysollib.mfxutil import Image, ImageTk, USE_PIL
-
-# Toolkit imports
-from pysollib.pysoltk import loadImage, copyImage, createImage, \
-        shadowImage, createBottom
+from pysollib.pysoltk import copyImage, createBottom, createImage, loadImage
+from pysollib.pysoltk import shadowImage
+from pysollib.resource import CSI
+from pysollib.settings import TOOLKIT
 
 # ************************************************************************
 # * Images
@@ -115,7 +109,7 @@ class Images:
             imagedir = self.d.findDir(cs_type, d)
         except Exception:
             pass
-        if (not USE_PIL and TOOLKIT is not 'kivy') or imagedir is None:
+        if (not USE_PIL and TOOLKIT != 'kivy') or imagedir is None:
             # load image
             img = self.__loadCard(filename+self.cs.ext, check_w, check_h)
             if USE_PIL and img is not None:
@@ -263,7 +257,7 @@ class Images:
         return self._bottom[0]
 
     def getBlankBottom(self):
-        if TOOLKIT is 'kivy':
+        if TOOLKIT == 'kivy':
             return self._bottom[0]
         return self._blank_bottom
 
@@ -500,9 +494,9 @@ class SubsampledImages(Images):
     def getShadow(self, ncards):
         return None
 
-    def _subsample(self, l, r):
+    def _subsample(self, images_list, r):
         s = []
-        for im in l:
+        for im in images_list:
             if im is None or r == 1:
                 s.append(im)
             else:
