@@ -25,38 +25,38 @@ import logging
 import math
 import traceback
 
-from kivy.graphics import Color
-from kivy.graphics import Rectangle
-from kivy.graphics import Line
-from kivy.graphics import Triangle
-
-from kivy.utils import platform
-from kivy.properties import StringProperty
-
+from kivy.animation import Animation
+from kivy.app import App
 from kivy.base import EventLoop
 from kivy.base import stopTouchApp
-from kivy.app import App
-from kivy.animation import Animation
-from kivy.core.audio import SoundLoader
+from kivy.cache import Cache
 from kivy.clock import Clock
-
-from kivy.uix.image import Image as KivyImage
-from kivy.uix.boxlayout import BoxLayout
-from kivy.uix.widget import Widget
-from kivy.uix.button import Button
+from kivy.config import Config
+from kivy.core.audio import SoundLoader
+from kivy.core.window import Window
+from kivy.graphics import Color
+from kivy.graphics import Line
+from kivy.graphics import Rectangle
+from kivy.graphics import Triangle
+from kivy.properties import StringProperty
+from kivy.uix.actionbar import ActionButton
+from kivy.uix.actionbar import ActionPrevious
+from kivy.uix.actionbar import ActionView
 from kivy.uix.behaviors import ButtonBehavior
+from kivy.uix.boxlayout import BoxLayout
+from kivy.uix.button import Button
+from kivy.uix.image import Image as KivyImage
 from kivy.uix.label import Label
 from kivy.uix.scrollview import ScrollView
-
-from kivy.uix.actionbar import ActionView
-from kivy.uix.actionbar import ActionPrevious
-from kivy.uix.actionbar import ActionButton
-
 from kivy.uix.treeview import TreeView
 from kivy.uix.treeview import TreeViewLabel
+from kivy.uix.widget import Widget
+from kivy.utils import platform
 
-from kivy.core.window import Window
-from kivy.cache import Cache
+from pysollib.kivy.androidperms import requestStoragePerm
+
+if platform != 'android':
+    Config.set('input', 'mouse', 'mouse,multitouch_on_demand')
 
 # =============================================================================
 
@@ -677,7 +677,10 @@ class LRectangle(Widget, LBase):
                     event = LEvent()
                     event.x = ppos[0]
                     event.y = ppos[1]
-                    self.group.bindings['<1>'](event)
+                    if touch.is_double_tap:
+                        self.group.bindings['<Double-1>'](event)
+                    else:
+                        self.group.bindings['<1>'](event)
                     return True
         return False
 
@@ -714,9 +717,27 @@ class LImageItem(BoxLayout, LBase):
         # ev. noch globales cache für stacks->game und cards->stack
         # einrichten. Aber: stacks hängt vom jeweiligen spiel ab.
 
-    def send_event_pressed_1(self, event):
-        if self.group and '<1>' in self.group.bindings:
-            self.group.bindings['<1>'](event)
+    def send_event_pressed_n(self, event, n):
+        if self.group and n in self.group.bindings:
+            self.group.bindings[n](event)
+
+    def send_event_pressed(self, touch, event):
+
+        if touch.is_double_tap:
+            self.send_event_pressed_n(event, '<Double-1>')
+        else:
+            button = 'left'
+            if 'button' in touch.profile:
+                button = touch.button
+            if button == 'left':
+                self.send_event_pressed_n(event, '<1>')
+                return
+            if button == 'middle':
+                self.send_event_pressed_n(event, '<2>')
+                return
+            if button == 'right':
+                self.send_event_pressed_n(event, '<3>')
+                return
 
     def on_touch_down(self, touch):
 
@@ -740,7 +761,7 @@ class LImageItem(BoxLayout, LBase):
                                 event.y = ppos[1]
                                 self.dragstart = touch.pos
                                 event.cardid = i
-                                self.send_event_pressed_1(event)
+                                self.send_event_pressed(touch, event)
                                 return True
 
             if self.group is not None:
@@ -768,7 +789,7 @@ class LImageItem(BoxLayout, LBase):
 
     def on_touch_up(self, touch):
         if touch.grab_current is self:
-                # release my grabbed touch!
+            # release my grabbed touch!
             print('ungrab')
             touch.ungrab(self)
             return True
@@ -1174,7 +1195,7 @@ class LMenu(ActionView, LBase):
         class MyActionPrev(ActionPrevious, LBase):
             pass
 
-        kw['app_icon'] = 'data/images/misc/pysol01.png'
+        kw['app_icon'] = 'data/images/icons/48x48/pysol.png'
         kw['with_previous'] = prev
         kw['size_hint'] = (.01, 1)
         self.ap = MyActionPrev(**kw)
@@ -1218,7 +1239,7 @@ class LMenu(ActionView, LBase):
                 pass
 
         for c in items:
-                # print ('LMenu: delete child %s' % c)
+            # print ('LMenu: delete child %s' % c)
             self.clear_widgets([c])
         for c in menues:
             # print ('LMenu: delete child %s' % c)
@@ -1547,6 +1568,12 @@ class LMainWindow(BoxLayout, LTkBase):
         self.workStack = LStack()
         self.app = None
 
+        '''
+        from kivy.graphics import opengl_utils
+        print('OPENGL support:')
+        print(opengl_utils.gl_get_extensions())
+        '''
+
         # self.touches = []
 
         # beispiel zu canvas (hintergrund)
@@ -1694,7 +1721,7 @@ class LMainWindow(BoxLayout, LTkBase):
             t = self.workStack.items[i]
             # print("stackkey:  %s" % str(t[0]))
             # print("stackitem: %s" % str(t[1]))
-            if t[0] is 'playground':
+            if t[0] == 'playground':
                 pass
             else:
                 if isinstance(t[1], LTopLevel):
@@ -1765,10 +1792,9 @@ class LApp(App):
 
     def doSize(self, obj, val):
         mval = self.mainWindow.size
-        logging.info("LApp: size changed %s - %s (%s)" % (obj, val, mval))
-        # Clock.schedule_once(self.delayedRebuild, 0.01)
-        Clock.schedule_once(self.makeDelayedRebuild(), 0.01)
-        # self.mainWindow.rebuildContainer()
+        if (val[0] != mval[0] and val[1] != mval[1]):
+            logging.info("LApp: size changed %s - %s (%s)" % (obj, val, mval))
+            Clock.schedule_once(self.makeDelayedRebuild(), 0.01)
         pass
 
     def on_start(self):
@@ -1785,6 +1811,8 @@ class LApp(App):
         self.mainloop = self.app.mainproc()  # Einrichten
         self.mainloop.send(None)                # Spielprozess starten
         logging.info("LApp: on_start processed")
+        # Android: Request missing android permissions.
+        requestStoragePerm()
 
     def on_stop(self):
         # Achtung wird u.U. 2 mal aufgerufen !!!
@@ -1838,12 +1866,6 @@ class LApp(App):
         except Exception:
             traceback.print_exc()
             pass
-        # save comments
-        try:
-            app.saveComments()
-        except Exception:
-            traceback.print_exc()
-            pass
         logging.info("LApp: on_pause - gamesaved")
 
         logging.info("LApp: on_pause, Window.size=%s" % str(Window.size))
